import { Body, Controller, Delete, Get, Param, ParseUUIDPipe, Patch, Post, Query } from '@nestjs/common';
import { PostService } from '../services/post.service';
import { PaginateOptions } from '@/modules/database/types';
@Controller('posts')
export class PostController {
    constructor(protected service: PostService) { }

    /**
     * 分页查询
     * @param options 
     */
    @Get()
    async list(@Query() options: PaginateOptions) {
        return this.service.paginate(options);
    }

    /**
     * 查询单篇文章
     * @param id 
     */
    @Get(':id')
    async detail(@Param('id', new ParseUUIDPipe()) id: string) {
        return this.service.detail(id);
    }

    /**
     * 新增文章
     * @param data 
     */
    @Post()
    async store(@Body() data: Record<string, any>) {
        return this.service.create(data);
    }

    /**
     * 更新文章
     * @param data 
     */
    @Patch()
    async update(@Body() data: Record<string, any>) {
        return this.service.update(data);
    }

    /**
     * 删除文章
     * @param id 
     */
    @Delete()
    async delete(@Param('id', new ParseUUIDPipe()) id: string) {
        return this.service.delete(id);
    }
}