import { DynamicModule, Module, Provider, Type } from '@nestjs/common';
import { TypeOrmModule, TypeOrmModuleOptions, getDataSourceToken } from '@nestjs/typeorm';
import { CUSTOM_REPOSITORY_METADATA } from './constants';
import { DataSource, ObjectType } from 'typeorm';

@Module({})
export class DatabaseModule {
    static forRoot(configRegister: () => TypeOrmModuleOptions): DynamicModule {
        return {
            module: DatabaseModule,
            global: true,
            imports: [TypeOrmModule.forRoot(configRegister())]
        };
    }

    static forRepository<T extends Type<any>>(
        repositories: T[], dataSourceName?: string
    ): DynamicModule {
        const providers: Provider[] = [];

        for (const Repository of repositories) {
            const entity = Reflect.getMetadata(CUSTOM_REPOSITORY_METADATA, Repository);
            if (!entity) {
                continue;
            }
            providers.push({
                inject: [getDataSourceToken(dataSourceName)],
                provide: Repository,
                useFactory: (dataSource: DataSource): InstanceType<typeof Repository> => {
                    const base = dataSource.getRepository<ObjectType<any>>(entity);
                    return new Repository(base.target, base.manager, base.queryRunner);
                },
            });
        }


        return {
            module: DatabaseModule,
            global: true,
            providers
        };
    }
}
